@@ -1,10 +1,11 @@
-;#=============================================================================
-;#	File:	subs.pm
-;#	Author:	Dave Oberholtzer, (daveo@obernet.com)
-;#			Copyright (c)2001, David Oberholtzer and Measurisk.
-;#	Date:	2001/03/23
-;#	Use:	Testing file for FameHLI::API functions
-;#=============================================================================
+#=============================================================================
+#	File:	subs.pm
+#	Author:	Dave Oberholtzer, (daveo@obernet.com)
+#			Copyright (c)2005, David Oberholtzer
+#	Date:	2001/03/23
+#	Use:	Testing file for FameHLI::API functions
+#	Mod:	
+#=============================================================================
 use		FileHandle;
 use		FameHLI::API::EXT;
 
@@ -12,11 +13,11 @@ my		$NA		=	"NA";
 my		$NC		=	"NC";
 my		$ND		=	"ND";
 
-;#=============================================================================
-;#		N U M   D A T A
-;#=============================================================================
-;#		Standardized data for numeric (and boolean) testing.
-;#=============================================================================
+#=============================================================================
+#		N U M   D A T A
+#=============================================================================
+#		Standardized data for numeric (and boolean) testing.
+#=============================================================================
 sub		NumData {
 		return(-2.2, -1.1, \$ND, 0, \$NC, 1.1, 2.2, 3.3, 4.4, 5.5, \$NA);
 }
@@ -188,6 +189,17 @@ my		$i;
 }
 
 
+;#=============================================================================
+;#		InteractiveFame
+;#=============================================================================
+sub		InteractiveFame {
+my		$fametest = "./fametest.out";
+		open(IN, $fametest) or die("'$fametest' isn't there.\n");
+my		$val = <IN>;
+		chomp($val);
+		return($val eq "WORKED");
+}
+
 ;#=============================================================================
 ;#		SkipResults
 ;#=============================================================================
